<?php
/*
   Plugin Name: TheShark products importer for eBay and woocommerce
   Plugin URI: http://wordpress.org/extend/plugins/woocommerce-reviews-manager/
   Version: 3.0.7
   Author: zizou1988
   Description: Import Products from eBay to woocommerce using theShark dropshipping
   Text Domain: TheShark dropshipping for ebay and woocommerce
   License: GPLv3
  */


/*
    "WordPress Plugin Template" Copyright (C) 2018 Michael Simpson  (email : michael.d.simpson@gmail.com)

    This following part of this file is part of WordPress Plugin Template for WordPress.

    WordPress Plugin Template is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    WordPress Plugin Template is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Contact Form to Database Extension.
    If not, see http://www.gnu.org/licenses/gpl-3.0.html
*/

$WoocommerceReviewsManager_minimalRequiredPhpVersion = '5.0';

/**
 * Check the PHP version and give a useful error message if the user's version is less than the required version
 * @return boolean true if version check passed. If false, triggers an error which WP will handle, by displaying
 * an error message on the Admin page
 */
function WoocommerceReviewsManager_noticePhpVersionWrong()
{
    global $WoocommerceReviewsManager_minimalRequiredPhpVersion;
    echo '<div class="updated fade">' .
        __('Error: plugin "wooshark dropshipping for ebay and woocommerce" requires a newer version of PHP to be running.',  'woocommerce-reviews-manager') .
        '<br/>' . __('Minimal version of PHP required: ', 'woocommerce-reviews-manager') . '<strong>' . $WoocommerceReviewsManager_minimalRequiredPhpVersion . '</strong>' .
        '<br/>' . __('Your server\'s PHP version: ', 'woocommerce-reviews-manager') . '<strong>' . phpversion() . '</strong>' .
        '</div>';
}


function WoocommerceReviewsManager_PhpVersionCheck()
{
    global $WoocommerceReviewsManager_minimalRequiredPhpVersion;
    if (version_compare(phpversion(), $WoocommerceReviewsManager_minimalRequiredPhpVersion) < 0) {
        add_action('admin_notices', 'WoocommerceReviewsManager_noticePhpVersionWrong');
        return false;
    }
    return true;
}


register_deactivation_hook(__FILE__, 'pluginprefix_function_to_run');
register_uninstall_hook(__FILE__, 'pluginprefix_function_to_run_remove');
function pluginprefix_function_to_run_remove()
{
    delete_option('_savedConfiguration_for_ebay');
    delete_option('urlApi_for_ebay');
    delete_option('appId_for_ebay');
    delete_option('syncRegularPrice_for_ebay');
    delete_option('syncSalePrice_for_ebay');
    delete_option('syncStock_for_ebay');
    delete_option('priceFormulaIntervalls_for_ebay');
    delete_option('isShippingCostEnabled_for_ebay');
    delete_option('isEnableAutomaticUpdateForAvailability_for_ebay');
    delete_option('isUpdateRegularPrice_for_ebay');
    delete_option('isUpdateSalePrice_for_ebay');
    delete_option('isUpdateStock_for_ebay');
    delete_option('onlyPublishProductWillSync_for_ebay');
    delete_option('enableAutomaticUpdates_for_ebay');
    delete_option('applyPriceFormulaAutomaticUpdate_for_ebay');
    wp_clear_scheduled_hook('wooshark-auto-update_for_ebay');
}
function pluginprefix_function_to_run()
{

    update_option('enableAutomaticUpdates_for_ebay', 'N');
    update_option('isEnableAutomaticUpdateForAvailability_for_ebay', 'N');
}

/**
 * Initialize internationalization (i18n) for this plugin.
 * References:
 *      http://codex.wordpress.org/I18n_for_WordPress_Developers
 *      http://www.wdmac.com/how-to-create-a-po-language-translation#more-631
 * @return void
 */
function WoocommerceReviewsManager_i18n_init()
{
    $pluginDir = dirname(plugin_basename(__FILE__));
    load_plugin_textdomain('woocommerce-reviews-manager', false, $pluginDir . '/languages/');
}


//////////////////////////////////
// Run initialization
/////////////////////////////////

// Initialize i18n
add_action('plugins_loadedi', 'WoocommerceReviewsManager_i18n_init');



// Initialize i18n
add_action('plugins_loadedi', 'WoocommerceReviewsManager_i18n_init');


// Run the version check.
// If it is successful, continue with initialization for this plugin
if (WoocommerceReviewsManager_PhpVersionCheck()) {
    // Only load and run the init function if we know PHP version can parse it
    include_once('woocommerce-reviews-manager_init.php');
    WoocommerceReviewsManager_init(__FILE__);
    initOriginalProductUrl_for_ebay();
}

function initOriginalProductUrl_for_ebay()
{
    add_action('post_submitbox_misc_actions', 'woo_add_custom_general_fields_originalProductUrl_for_ebay', 20);
    function woo_add_custom_general_fields_originalProductUrl_for_ebay()
    {
        echo ' 
        <button type="button" style="margin:10px; "  class="btn btn-primary" id="openOriginalProductUrl" data-target=".bd-example-modal-lg"> Open Original product url (wooshark)</button>
        <div class="loader2" style="display:none"><div></div><div></div><div></div><div></div></div>';
    }
}


function my_admin_scripts_init_for_ebay($hook_suffix)
{

    if ('post.php' == $hook_suffix || 'post-new.php' == $hook_suffix) {

        // add_action('wp_enqueue_scripts', 'jquery_add_to_contact');
        // wp_enqueue_script('bootstrap', plugin_dir_url(__FILE__) . 'js/bootstrap.min.js', array('jquery'), NULL, false);
        wp_enqueue_style('bootstrapCss', plugin_dir_url(__FILE__) . 'css/bootstrap.min.css');
        wp_enqueue_script('original', plugin_dir_url(__FILE__) . 'js/original.js', array('jquery'), NULL, false);
        wp_localize_script(
            'original',
            'wooshark_params',
            array(
                'ajaxurl' => admin_url('admin-ajax.php'),
                'nonce' => wp_create_nonce('ajax-nonce')
            )
        );
    }
}
add_action('admin_enqueue_scripts', 'my_admin_scripts_init_for_ebay');







// 
// 
// 
// 
// 
// 
// 
// 

// 

// 
// 
// 
// 
if (get_option(base64_decode('aXNFbmFibGVBdXRvbWF0aWNVcGRhdGVGb3JBdmFpbGFiaWxpdHlfZm9yX2ViYXk=')) == base64_decode('WQ==') || get_option(base64_decode('ZW5hYmxlQXV0b21hdGljVXBkYXRlc19mb3JfZWJheQ==')) == base64_decode('WQ==')) {
    if (get_option(base64_decode('c3RvcF9hdXRvbWF0aWNfdXBkYXRlX2Zvcl9lYmF5')) != base64_decode('c3RvcA==')) {
        if (!wp_next_scheduled(base64_decode('d29vc2hhcmstYXV0by11cGRhdGVfZm9yX2ViYXk='))) {
            wp_schedule_event(time(), base64_decode('ZGFpbHk='), base64_decode('d29vc2hhcmstYXV0by11cGRhdGVfZm9yX2ViYXk='));
        }
        add_action(base64_decode('d29vc2hhcmstYXV0by11cGRhdGVfZm9yX2ViYXk='), base64_decode('YXV0b1VwZGF0ZVN0b2NrQW5kUHJpY2VfZm9yX2ViYXk='));
        function autoUpdateStockAndPrice_for_ebay()
        {
            $d0 = true;
            $y1 = true;
            $e2 = true;
            $l3 = true;
            $w4 = true;
            $m5 = false;
            $e6 = true;
            $g7 = get_option(base64_decode('ZW5hYmxlQXV0b21hdGljVXBkYXRlc19mb3JfZWJheQ=='));
            $g8 = get_option(base64_decode('aXNFbmFibGVBdXRvbWF0aWNVcGRhdGVGb3JBdmFpbGFiaWxpdHlfZm9yX2ViYXk='));
            if (get_option(base64_decode('YXBwbHlQcmljZUZvcm11bGFBdXRvbWF0aWNVcGRhdGVfZm9yX2ViYXk=')) == base64_decode('WQ==')) {
                $e6 = true;
            } else {
                $e6 = false;
            }
            if (get_option(base64_decode('c3luY1N0b2NrX2Zvcl9lYmF5')) == base64_decode('WQ==')) {
                $y1 = true;
            } else {
                $y1 = false;
            }
            if (get_option(base64_decode('c3luY1NhbGVQcmljZQ==')) == base64_decode('WQ==')) {
                $e2 = true;
            } else {
                $e2 = false;
            }
            if (get_option(base64_decode('c3luY1JlZ3VsYXJQcmljZV9mb3JfZWJheQ==')) == base64_decode('WQ==')) {
                $l3 = true;
            } else {
                $l3 = false;
            }
            $m9 = array(base64_decode('cHVibGlzaA=='), base64_decode('ZHJhZnQ='));
            $s10 = get_option(base64_decode('cHJpY2VGb3JtdWxhSW50ZXJ2YWxsc19mb3JfZWJheQ=='));
            $g11 = array(base64_decode('cG9zdF90eXBl') => base64_decode('cHJvZHVjdA=='), base64_decode('cG9zdHNfcGVyX3BhZ2U=') => 2000, base64_decode('cG9zdF9zdGF0dXM=') => $m9, base64_decode('bWV0YV9xdWVyeQ==') => array(array(base64_decode('a2V5') => base64_decode('cHJvZHVjdFVybA=='), base64_decode('dmFsdWU=') => base64_decode('ZWJheS4='), base64_decode('Y29tcGFyZQ==') => base64_decode('TElLRQ=='))));
            $j12 = new WP_Query($g11);
            $n13 = array();
            $i14 = array();
            if ($j12->have_posts()) {
                while ($j12->have_posts()) : $j12->the_post();
                    $r15 = get_the_ID();
                    $c16 = wc_get_product($r15);
                    $p17 = $c16->get_sku();
                    $w18 = $r15;
                    if ($c16->is_type(base64_decode('c2ltcGxl'))) {
                        $b19 = get_post_meta($r15, base64_decode('cHJvZHVjdFVybA=='), true);
                        $u20 = curl_init();
                        curl_setopt($u20, CURLOPT_URL, $b19);
                        curl_setopt($u20, CURLOPT_CUSTOMREQUEST, base64_decode(base64_decode('UjBWVQ==')));
                        curl_setopt($u20, CURLOPT_FOLLOWLOCATION, TRUE);
                        curl_setopt($u20, CURLOPT_RETURNTRANSFER, true);
                        $m21 = curl_exec($u20);
                        curl_close($u20);
                        // if (strpos($m21, base64_decode('TU9EVUxFX05PVF9GT1VORA==')) == true && $g8 == base64_decode('WQ==')) {
                        if ((strpos($m21, 'MODULE_NOT_FOUND') == true  || strpos($m21, 'is out of stock'))  && $g8 == base64_decode('WQ==')) {
                            if (isset($w18)) {
                                update_post_meta($w18, base64_decode('bGFzdFVwZGF0ZWQ='), base64_decode('cHJvZHVjdCBpcyBvdXQgb2Ygc3RvY2s='));
                                $p22 = update_post_meta($w18, base64_decode('aXNFeHBpcmVkX2ViYXk='), base64_decode('dHJ1ZQ=='));
                                $q23 = array(base64_decode('SUQ=') => $w18, base64_decode('cG9zdF9zdGF0dXM=') => base64_decode('ZHJhZnQ='));
                                update_post_meta($w18, '_manage_stock', 'yes');
                                update_post_meta($w18, '_stock', 0);
                                wp_update_post($q23);
                            }
                        } else if (strpos($m21, base64_decode('aXNNb2RlbA==')) == true && $g7 == base64_decode('WQ==')) {
                            $w24 = base64_decode('LyJpc01vZGVsIjouKj99fS9pbQ==');
                            if (preg_match($w24, $m21, $f25)) {
                                if (isset($f25) && isset($f25[0])) {
                                    $e26 = json_decode(base64_decode('ew==') . $f25[0], true);
                                    if (isset($e26) && count($e26)) {
                                        foreach ($e26 as $e27) {
                                            $g28 = $e27[base64_decode('cmVtYWluUXR5')];
                                            $b29 = null;
                                            if (isset($e27[base64_decode('YmluUHJpY2VEb3VibGU=')])) {
                                                $b29 = $e27[base64_decode('YmluUHJpY2VEb3VibGU=')];
                                            } else if (isset($e27[base64_decode('YmlkUHJpY2VEb3VibGU=')])) {
                                                $b29 = $e27[base64_decode('YmlkUHJpY2VEb3VibGU=')];
                                            }
                                            if (isset($b29) && isset($g28)) {
                                                if (isset($b29) && $l3 == true) {
                                                    if ($e6 == true) {
                                                        $p22 = applyFormula_for_ebay($b29, $s10);
                                                        update_post_meta($w18, base64_decode('X3ByaWNl'), $p22);
                                                        update_post_meta($w18, base64_decode('X3JlZ3VsYXJfcHJpY2U='), $p22);
                                                    } else {
                                                        $p22 = $b29;
                                                        update_post_meta($w18, base64_decode('X3ByaWNl'), $p22);
                                                        update_post_meta($w18, base64_decode('X3JlZ3VsYXJfcHJpY2U='), $p22);
                                                    }
                                                }
                                                if (isset($g28) && $g28 > -1 && $y1 == true) {
                                                    update_post_meta($w18, base64_decode('X21hbmFnZV9zdG9jaw=='), base64_decode('eWVz'));
                                                    update_post_meta($w18, base64_decode('X3N0b2Nr'), $g28);
                                                }
                                                update_post_meta($w18, base64_decode('bGFzdFVwZGF0ZWQ='), date(base64_decode('WS1tLWQgSDppOnM=')));
                                            } else {
                                                update_post_meta($w18, base64_decode('bGFzdFVwZGF0ZWQ='), base64_decode('UHJvZHVjdCBtYXliZSBvdXQgb2Ygc3RvY2sgLSBjYW5ub3QgZ2V0IHByaWNlIGFuZCBxdWFudGl0eQ=='));
                                            }
                                        }
                                    } else {
                                        update_post_meta($w18, base64_decode('bGFzdFVwZGF0ZWQ='), base64_decode('IGNhbm5vdCB1cGRhdGUgcHJvZHVjdCAtIA==') . $f25[0]);
                                    }
                                } else {
                                    update_post_meta($w18, base64_decode('bGFzdFVwZGF0ZWQ='), base64_decode('Y2Fubm90IHVwZGF0ZSBwcm9kdWN0IC0gbWF0Y2hpbmcgaXNzdWU='));
                                }
                            } else {
                                update_post_meta($w18, base64_decode('bGFzdFVwZGF0ZWQ='), base64_decode('Y2Fubm90IG1hdGNoIHByb2R1Y3QgcmVn'));
                            }
                        } else if (strpos($m21, base64_decode('Y2xhc3M9ImltZ0NhcHRjaGEi')) == true) {
                            update_post_meta($w18, base64_decode('bGFzdFVwZGF0ZWQ='), base64_decode('Y2Fubm90IGdldCBkZXRhaWxzIG9mIHRoZSBuZXcgcHJvZHVjdCBwbGVhc2UgdmVyaWZ5IHRoaXMgYWxpZXhwcmVzcyBwYWdl') . $m21);
                            break;
                        }
                        sleep(5);
                    } else if ($c16->is_type(base64_decode('dmFyaWFibGU='))) {
                        array_push($i14, $p17);
                    } else {
                        update_post_meta($w18, base64_decode('bGFzdFVwZGF0ZWQ='), base64_decode('dHlwZSBvZiBwcm9kdWN0IGlzIHVua25vd24='));
                    }
                endwhile;
            } else {
                echo __(base64_decode(base64_decode('VG04Z2NISnZaSFZqZEhNZ1ptOTFibVE9')));
            }
            $u30 = array_chunk($i14, 19);
            $r31 = get_option(base64_decode('YXBwSWRfZm9yX2ViYXk='));
            $i32 = get_option(base64_decode('dXJsQXBpX2Zvcl9lYmF5'));
            if (isset($r31) && $r31 != base64_decode('Tg==')) {
                foreach ($u30 as $n33) {
                    $p34 = implode(base64_decode('LA=='), $n33);
                    $u20 = curl_init();
                    $z35 = $i32 . base64_decode('JmFwcGlkPQ==') . $r31 . base64_decode('JnNpdGVpZD0wJnZlcnNpb249MTA1NyZJdGVtSUQ9') . $p34 . base64_decode('JkluY2x1ZGVTZWxlY3Rvcj1WYXJpYXRpb25z');
                    curl_setopt($u20, CURLOPT_URL, $z35);
                    curl_setopt($u20, CURLOPT_CUSTOMREQUEST, base64_decode(base64_decode('UjBWVQ==')));
                    curl_setopt($u20, CURLOPT_FOLLOWLOCATION, TRUE);
                    curl_setopt($u20, CURLOPT_RETURNTRANSFER, true);
                    $m21 = curl_exec($u20);
                    curl_close($u20);
                    $y36 = json_decode($m21, true);
                    if (isset($y36) && isset($y36[base64_decode('SXRlbQ==')]) && count($y36[base64_decode('SXRlbQ==')])) {
                        foreach ($y36[base64_decode('SXRlbQ==')] as $c16) {
                            $w18 = wc_get_product_id_by_sku($c16[base64_decode('SXRlbUlE')]);
                            $j37 = wc_get_product($w18);
                            $x38 = $j37->get_available_variations();
                            if (isset($x38) && count($x38) > 0) {
                                foreach ($x38 as $k39) {
                                    if (isset($k39)) {
                                        $n40 = $k39[base64_decode('dmFyaWF0aW9uX2lk')];
                                        $i41 = false;
                                        if (isset($n40) && isset($c16[base64_decode('VmFyaWF0aW9ucw==')][base64_decode('VmFyaWF0aW9u')]) && count($c16[base64_decode('VmFyaWF0aW9ucw==')][base64_decode('VmFyaWF0aW9u')])) {
                                            foreach ($c16[base64_decode('VmFyaWF0aW9ucw==')][base64_decode('VmFyaWF0aW9u')] as $x42) {
                                                if (isset($x42[base64_decode('U0tV')]) && $x42[base64_decode('U0tV')] == $k39[base64_decode(base64_decode('YzJ0MQ=='))]) {
                                                    $i41 = true;
                                                    $b29 = $x42[base64_decode('U3RhcnRQcmljZQ==')][base64_decode('VmFsdWU=')];
                                                    $t43 = $x42['Quantity'];
                                                    $soldQuantity = $x42['SellingStatus']['QuantitySold'];
                                                    if(isset($soldQuantity) && $soldQuantity > 0){
                                                        $t43 = $t43 - $soldQuantity;
                                                    }

                                                    // let soldQuantity = item.SellingStatus ? item.SellingStatus.QuantitySold : 0;

                                                    if (isset($b29) && $l3 == true) {
                                                        $p22 = applyFormula_for_ebay($b29, $s10);
                                                        if ($e6 == true) {
                                                            $p22 = applyFormula_for_ebay($b29, $s10);
                                                        } else {
                                                            $p22 = $b29;
                                                        }
                                                        update_post_meta($n40, base64_decode('X3ByaWNl'), $p22);
                                                        update_post_meta($n40, base64_decode('X3JlZ3VsYXJfcHJpY2U='), $p22);
                                                        wc_delete_product_transients($n40);
                                                    }
                                                    if (isset($t43) && $t43 > -1 && $y1 == true) {
                                                        update_post_meta($n40, '_manage_stock', 'yes');
                                                        update_post_meta($n40, '_stock', $t43);
                                                    }

                                                }
                                            }
                                        }
                                    }
                                }
                                update_post_meta($w18, base64_decode('bGFzdFVwZGF0ZWQ='), date(base64_decode('WS1tLWQgSDppOnM=')));
                            } else {
                                update_post_meta($w18, base64_decode('bGFzdFVwZGF0ZWQ='), base64_decode('Y2Fubm90IHVwZGF0ZSBwcm9kdWN0LCBtaXNzaW5nIHZhcmlhdGlvbnM='));
                            }
                        }
                    }
                    sleep(1);
                }
            }
        }
    }
}
function applyFormula_for_ebay($a44, $f45)
{
    $l46 = $a44;
    if (isset($f45) && count($f45)) {
        foreach ($f45 as $b47) {
            $i48 = $b47[base64_decode(base64_decode('YldsdQ=='))];
            $c49 = $b47[base64_decode(base64_decode('YldGNA=='))];
            $o50 = $b47[base64_decode(base64_decode('YlhWc2RHbHdiSGs9'))];
            $q51 = $b47[base64_decode(base64_decode('WVdSa2FYUnBiMjQ9'))];
            if (!isset($q51)) {
                $q51 = 0;
            }
            if ($a44 > $i48 && $a44 < $c49 && $o50 > 0) {
                if ($o50) {
                    $l46 = $a44 + (($a44 * $o50) / 100) + $q51;
                }
            }
        }
    }
    return $l46;
}
if (get_option(base64_decode('aXNTaGlwcGluZ0Nvc3RFbmFibGVkX2Zvcl9lYmF5')) == base64_decode('WQ==')) {
    function Shipping_method_1()
    {
        if (!class_exists(base64_decode('V0NfWW91cl9TaGlwcGluZ19tZXRob2RfMQ=='))) {
            class WC_Your_Shipping_method_1 extends WC_Shipping_Method
            {
                /**
                 * Constructor for your shipping class
                 *
                 * @access public
                 * @return void
                 */ public function __construct()
                {
                    $this->id = base64_decode('U2hpcHBpbmdfbWV0aG9kXzE=');
                    $this->method_title = __(base64_decode('U2hpcHBpbmdfbWV0aG9kXzE='));
                    $this->method_description = __(base64_decode('U2hpcHBpbmdfbWV0aG9kXzE='));
                    $this->title = base64_decode('U2hpcHBpbmdfbWV0aG9kXzE=');
                    $this->init();
                }
                /**
                 * Init your settings
                 *
                 * @access public
                 * @return void
                 */ function init()
                {
                    $this->init_form_fields();
                    $this->init_settings();
                    add_action(base64_decode('d29vY29tbWVyY2VfdXBkYXRlX29wdGlvbnNfc2hpcHBpbmdf') . $this->id, array($this, base64_decode('cHJvY2Vzc19hZG1pbl9vcHRpb25z')));
                }
                /**
                 * calculate_shipping function.
                 *
                 * @access public
                 * @param mixed $package
                 * @return void
                 */ public function calculate_shipping($s56 = array())
                {
                    $o57 = base64_decode('MA==');
                    $j58 = array(base64_decode('aWQ=') => $this->id, base64_decode('bGFiZWw=') => $this->title, base64_decode('Y29zdA==') => $o57);
                    $this->add_rate($j58);
                }
            }
        }
    }
    add_action(base64_decode('d29vY29tbWVyY2Vfc2hpcHBpbmdfaW5pdA=='), base64_decode('U2hpcHBpbmdfbWV0aG9kXzE='));
    function add_your_Shipping_method_1($l59)
    {
        $l59[] = base64_decode('V0NfWW91cl9TaGlwcGluZ19tZXRob2RfMQ==');
        return $l59;
    }
    add_filter(base64_decode('d29vY29tbWVyY2Vfc2hpcHBpbmdfbWV0aG9kcw=='), base64_decode('YWRkX3lvdXJfU2hpcHBpbmdfbWV0aG9kXzE='));
    function shipping_method_shipping_method_2()
    {
        if (!class_exists(base64_decode('V0NfWW91cl9TaGlwcGluZ19NZXRob2Rfc2hpcHBpbmdfbWV0aG9kXzI='))) {
            class WC_Your_Shipping_Method_shipping_method_2 extends WC_Shipping_Method
            {
                /**
                 * Constructor for your shipping class
                 *
                 * @access public
                 * @return void
                 */ public function __construct()
                {
                    $this->id = base64_decode('c2hpcHBpbmdfbWV0aG9kXzI=');
                    $this->method_title = __(base64_decode('c2hpcHBpbmdfbWV0aG9kXzI='));
                    $this->method_description = __(base64_decode('c2hpcHBpbmdfbWV0aG9kXzI='));
                    $this->title = base64_decode('c2hpcHBpbmdfbWV0aG9kXzI=');
                    $this->init();
                }
                /**
                 * Init your settings
                 *
                 * @access public
                 * @return void
                 */ function init()
                {
                    $this->init_form_fields();
                    $this->init_settings();
                    add_action(base64_decode('d29vY29tbWVyY2VfdXBkYXRlX29wdGlvbnNfc2hpcHBpbmdf') . $this->id, array($this, base64_decode('cHJvY2Vzc19hZG1pbl9vcHRpb25z')));
                }
                /**
                 * calculate_shipping function.
                 *
                 * @access public
                 * @param mixed $package
                 * @return void
                 */ public function calculate_shipping($s56 = array())
                {
                    $o57 = base64_decode('MA==');
                    $j58 = array(base64_decode('aWQ=') => $this->id, base64_decode('bGFiZWw=') => $this->title, base64_decode('Y29zdA==') => $o57);
                    $this->add_rate($j58);
                }
            }
        }
    }
    add_action(base64_decode('d29vY29tbWVyY2Vfc2hpcHBpbmdfaW5pdA=='), base64_decode('c2hpcHBpbmdfbWV0aG9kX3NoaXBwaW5nX21ldGhvZF8y'));
    function add_your_shipping_method_shipping_method_2($l59)
    {
        $l59[] = base64_decode('V0NfWW91cl9TaGlwcGluZ19NZXRob2Rfc2hpcHBpbmdfbWV0aG9kXzI=');
        return $l59;
    }
    add_filter(base64_decode('d29vY29tbWVyY2Vfc2hpcHBpbmdfbWV0aG9kcw=='), base64_decode('YWRkX3lvdXJfc2hpcHBpbmdfbWV0aG9kX3NoaXBwaW5nX21ldGhvZF8y'));
    function shipping_method_3()
    {
        if (!class_exists(base64_decode('V0NfWW91cl9zaGlwcGluZ19tZXRob2RfMw=='))) {
            class WC_Your_shipping_method_3 extends WC_Shipping_Method
            {
                /**
                 * Constructor for your shipping class
                 *
                 * @access public
                 * @return void
                 */ public function __construct()
                {
                    $this->id = base64_decode('c2hpcHBpbmdfbWV0aG9kXzM=');
                    $this->method_title = __(base64_decode('c2hpcHBpbmdfbWV0aG9kXzM='));
                    $this->method_description = __(base64_decode('c2hpcHBpbmdfbWV0aG9kXzM='));
                    $this->title = base64_decode('c2hpcHBpbmdfbWV0aG9kXzM=');
                    $this->init();
                }
                /**
                 * Init your settings
                 *
                 * @access public
                 * @return void
                 */ function init()
                {
                    $this->init_form_fields();
                    $this->init_settings();
                    add_action(base64_decode('d29vY29tbWVyY2VfdXBkYXRlX29wdGlvbnNfc2hpcHBpbmdf') . $this->id, array($this, base64_decode('cHJvY2Vzc19hZG1pbl9vcHRpb25z')));
                }
                /**
                 * calculate_shipping function.
                 *
                 * @access public
                 * @param mixed $package
                 * @return void
                 */ public function calculate_shipping($s56 = array())
                {
                    $o57 = base64_decode('MA==');
                    $j58 = array(base64_decode('aWQ=') => $this->id, base64_decode('bGFiZWw=') => $this->title, base64_decode('Y29zdA==') => $o57);
                    $this->add_rate($j58);
                }
            }
        }
    }
    add_action(base64_decode('d29vY29tbWVyY2Vfc2hpcHBpbmdfaW5pdA=='), base64_decode('c2hpcHBpbmdfbWV0aG9kXzM='));
    function add_your_shipping_method_3($l59)
    {
        $l59[] = base64_decode('V0NfWW91cl9zaGlwcGluZ19tZXRob2RfMw==');
        return $l59;
    }
    add_filter(base64_decode('d29vY29tbWVyY2Vfc2hpcHBpbmdfbWV0aG9kcw=='), base64_decode('YWRkX3lvdXJfc2hpcHBpbmdfbWV0aG9kXzM='));
    function shipping_method_4()
    {
        if (!class_exists(base64_decode('V0NfWW91cl9zaGlwcGluZ19tZXRob2RfNA=='))) {
            class WC_Your_shipping_method_4 extends WC_Shipping_Method
            {
                /**
                 * Constructor for your shipping class
                 *
                 * @access public
                 * @return void
                 */ public function __construct()
                {
                    $this->id = base64_decode('c2hpcHBpbmdfbWV0aG9kXzQ=');
                    $this->method_title = __(base64_decode('c2hpcHBpbmdfbWV0aG9kXzQ='));
                    $this->method_description = __(base64_decode('c2hpcHBpbmdfbWV0aG9kXzQ='));
                    $this->title = base64_decode('c2hpcHBpbmdfbWV0aG9kXzQ=');
                    $this->init();
                }
                /**
                 * Init your settings
                 *
                 * @access public
                 * @return void
                 */ function init()
                {
                    $this->init_form_fields();
                    $this->init_settings();
                    add_action(base64_decode('d29vY29tbWVyY2VfdXBkYXRlX29wdGlvbnNfc2hpcHBpbmdf') . $this->id, array($this, base64_decode('cHJvY2Vzc19hZG1pbl9vcHRpb25z')));
                }
                /**
                 * calculate_shipping function.
                 *
                 * @access public
                 * @param mixed $package
                 * @return void
                 */ public function calculate_shipping($s56 = array())
                {
                    $o57 = base64_decode('MA==');
                    $j58 = array(base64_decode('aWQ=') => $this->id, base64_decode('bGFiZWw=') => $this->title, base64_decode('Y29zdA==') => $o57);
                    $this->add_rate($j58);
                }
            }
        }
    }
    add_action(base64_decode('d29vY29tbWVyY2Vfc2hpcHBpbmdfaW5pdA=='), base64_decode('c2hpcHBpbmdfbWV0aG9kXzQ='));
    function add_your_shipping_method_4($l59)
    {
        $l59[] = base64_decode('V0NfWW91cl9zaGlwcGluZ19tZXRob2RfNA==');
        return $l59;
    }
    add_filter(base64_decode('d29vY29tbWVyY2Vfc2hpcHBpbmdfbWV0aG9kcw=='), base64_decode('YWRkX3lvdXJfc2hpcHBpbmdfbWV0aG9kXzQ='));
    function shipping_method_5()
    {
        if (!class_exists(base64_decode('V0NfWW91cl9zaGlwcGluZ19tZXRob2RfNQ=='))) {
            class WC_Your_shipping_method_5 extends WC_Shipping_Method
            {
                /**
                 * Constructor for your shipping class
                 *
                 * @access public
                 * @return void
                 */ public function __construct()
                {
                    $this->id = base64_decode('c2hpcHBpbmdfbWV0aG9kXzU=');
                    $this->method_title = __(base64_decode('c2hpcHBpbmdfbWV0aG9kXzU='));
                    $this->method_description = __(base64_decode('c2hpcHBpbmdfbWV0aG9kXzU='));
                    $this->title = base64_decode('c2hpcHBpbmdfbWV0aG9kXzU=');
                    $this->init();
                }
                /**
                 * Init your settings
                 *
                 * @access public
                 * @return void
                 */ function init()
                {
                    $this->init_form_fields();
                    $this->init_settings();
                    add_action(base64_decode('d29vY29tbWVyY2VfdXBkYXRlX29wdGlvbnNfc2hpcHBpbmdf') . $this->id, array($this, base64_decode('cHJvY2Vzc19hZG1pbl9vcHRpb25z')));
                }
                /**
                 * calculate_shipping function.
                 *
                 * @access public
                 * @param mixed $package
                 * @return void
                 */ public function calculate_shipping($s56 = array())
                {
                    $o57 = base64_decode('MA==');
                    $j58 = array(base64_decode('aWQ=') => $this->id, base64_decode('bGFiZWw=') => $this->title, base64_decode('Y29zdA==') => $o57);
                    $this->add_rate($j58);
                }
            }
        }
    }
    add_action(base64_decode('d29vY29tbWVyY2Vfc2hpcHBpbmdfaW5pdA=='), base64_decode('c2hpcHBpbmdfbWV0aG9kXzU='));
    function add_your_shipping_method_5($l59)
    {
        $l59[] = base64_decode('V0NfWW91cl9zaGlwcGluZ19tZXRob2RfNQ==');
        return $l59;
    }
    add_filter(base64_decode('d29vY29tbWVyY2Vfc2hpcHBpbmdfbWV0aG9kcw=='), base64_decode('YWRkX3lvdXJfc2hpcHBpbmdfbWV0aG9kXzU='));
    add_filter('woocommerce_package_rates', 'custom_shipping_costs_for_ebay', 20, 2);
    function custom_shipping_costs_for_ebay($rates, $package)
    {

        // $file = plugin_dir_path(__FILE__) . '/test.txt';
//   $open = fopen($file, "w");
//   fwrite($open, '---R----------RR3');

        $pp = $package[base64_decode('ZGVzdGluYXRpb24=')][base64_decode('Y291bnRyeQ==')];
        $postCode = $package[base64_decode('ZGVzdGluYXRpb24=')][ 'postcode' ];
        $tt = WC()->cart->get_cart_contents_count();
        foreach ($package[base64_decode('Y29udGVudHM=')] as $item_id => $values) {
            $pr = $values[base64_decode('ZGF0YQ==')];
            // fwrite($open, 'before parent-id --' );

            $parentId = $pr->get_parent_id();

            // fwrite($open, 'parent-id' . $parentId );

            if(isset($parentId) && $parentId > 0){
                $p = wc_get_product($parentId);
                $pu = get_post_meta($parentId, base64_decode('cHJvZHVjdFVybA=='), true);
            }
            

            else if (isset($parentId) && $parentId < 1){
                // fwrite($open, 'start' . '---' . $p . '....' .$pu );
                $p = wc_get_product($pr->get_id());
                $pu = get_post_meta($pr->get_id(), base64_decode('cHJvZHVjdFVybA=='), true);
                // fwrite($open, '....' .$pu );
            }
            

            if (isset($pu) && strpos($pu, base64_decode('ZWJheS4=')) !== false) {

                // fwrite($open, 'eeee');

                $ss = $p->get_sku();

                // fwrite($open, 'qqqqq' . $ss);


                $curl = curl_init();
                $appId = get_option(base64_decode('YXBwSWRfZm9yX2ViYXk='));
                $urlApi = get_option(base64_decode('dXJsQXBpX2Zvcl9lYmF5'));
                $finalUrl = base64_decode('aHR0cHM6Ly9vcGVuLmFwaS5lYmF5LmNvbS9zaG9wcGluZz9jYWxsbmFtZT1HZXRTaGlwcGluZ0Nvc3RzJnJlc3BvbnNlZW5jb2Rpbmc9SlNPTiZhcHBpZD0=') . $appId . base64_decode('JnNpdGVpZD0wJnZlcnNpb249NTE3Jkl0ZW1JRD0=') . $ss . base64_decode('JkRlc3RpbmF0aW9uQ291bnRyeUNvZGU9') . $pp . base64_decode('JkluY2x1ZGVEZXRhaWxzPXRydWUmUXVhbnRpdHlTb2xkPQ==') . $tt;
                if(isset($postCode)){
                    $finalUrl  = $finalUrl . '&DestinationPostalCode='.$postCode;
                }
                curl_setopt($curl, CURLOPT_URL, $finalUrl);
                curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
                $o = curl_exec($curl);
                curl_close($curl);
                $jr = json_decode($o);

                // fwrite($open, 'final url ' . $finalUrl);

                // fwrite($open, 'xxx' . json_decode($jr));

                if (isset($jr) && $jr->Ack == base64_decode('U3VjY2Vzcw==')) {
                    // fwrite($open, '222');
                    $shippingDetails = $jr->ShippingDetails;
                    if (isset($shippingDetails) && isset($shippingDetails->ShippingServiceOption) && count($shippingDetails->ShippingServiceOption)) {
                        // fwrite($open, '333');
                        
                        if (is_null($jr)) {
                            foreach ($rates as $rate_key => $rate) {
                                unset($rates[$rate_key]);
                            }
                        } else {
                            // fwrite($open, '444');
                            $list_ship = array(base64_decode('U2hpcHBpbmdfbWV0aG9kXzE='), base64_decode('c2hpcHBpbmdfbWV0aG9kXzI='), base64_decode('c2hpcHBpbmdfbWV0aG9kXzM='), base64_decode('c2hpcHBpbmdfbWV0aG9kXzQ='), base64_decode('c2hpcHBpbmdfbWV0aG9kXzU='));
                            foreach ($shippingDetails->ShippingServiceOption as $key => $value) {
                                // fwrite($open, '555');
                                if (isset($list_ship[$key]) && isset($list_ship[$key]) && $value->ShippingServiceName && isset($rates[$list_ship[$key]])) {
                                    $companyName = $value->ShippingServiceName;
                                    $rates[$list_ship[$key]]->label = $companyName . base64_decode('ICAtIERlbGl2ZXJ5IGRhdGU6IA==') . $value->ShippingTimeMin . base64_decode('IGRheXM=');
                                    $rates[$list_ship[$key]]->cost = $value->ShippingServiceCost->Value;
                                    if ($value->ShippingServiceCost->Value == 0) {
                                        $rates[$list_ship[$key]]->label = $rates[$list_ship[$key]]->label . base64_decode('IChGcmVlIHNoaXBwaW5nKSA=');
                                    }
                                }
                            }
                            for ($i = count($shippingDetails->ShippingServiceOption); $i < count($list_ship); $i++) {
                                unset($rates[$list_ship[$i]]);
                            }
                        }
                    } else if (isset($shippingDetails) && isset($shippingDetails->InternationalShippingServiceOption) && count($shippingDetails->InternationalShippingServiceOption)) {
                        if (is_null($jr)) {
                            foreach ($rates as $rate_key => $rate) {
                                unset($rates[$rate_key]);
                            }
                        } else {
                            foreach ($rates as $rate_key => $rate) { }
                            $list_ship = array(base64_decode('U2hpcHBpbmdfbWV0aG9kXzE='), base64_decode('c2hpcHBpbmdfbWV0aG9kXzI='), base64_decode('c2hpcHBpbmdfbWV0aG9kXzM='), base64_decode('c2hpcHBpbmdfbWV0aG9kXzQ='), base64_decode('c2hpcHBpbmdfbWV0aG9kXzU='));
                            foreach ($shippingDetails->InternationalShippingServiceOption as $key => $value) {
                                if (isset($list_ship[$key]) && isset($list_ship[$key]) && $value->ShippingServiceName && isset($rates[$list_ship[$key]])) {
                                    $companyName = $value->ShippingServiceName;
                                    $rates[$list_ship[$key]]->label = $companyName;
                                    if (isset($value->ShippingTimeMin)) {
                                        $rates[$list_ship[$key]]->label = $rates[$list_ship[$key]]->label . base64_decode('ICAtIERlbGl2ZXJ5IGRhdGU6IA==') . $value->ShippingTimeMin . base64_decode('IGRheXM=');
                                    }
                                    $rates[$list_ship[$key]]->cost = $value->ShippingServiceCost->Value;
                                    if ($value->ShippingServiceCost->Value == 0) {
                                        $rates[$list_ship[$key]]->label = $rates[$list_ship[$key]]->label . base64_decode('IChGcmVlIHNoaXBwaW5nKSA=');
                                    }
                                }
                            }
                            for ($i = count($shippingDetails->InternationalShippingServiceOption); $i < count($list_ship); $i++) {
                                unset($rates[$list_ship[$i]]);
                            }
                        }
                    } else {
                        foreach ($rates as $rate_key => $rate) {
                            unset($rates[$rate_key]);
                        }
                    }
                } else {
                    foreach ($rates as $rate_key => $rate) {
                        unset($rates[$rate_key]);
                    }
                }
            } else {
                foreach ($rates as $rate_key => $rate) {
                    unset($rates[$rate_key]);
                }
            }
        }

        // fclose($open);
        return $rates;
    }
}
